@@ -1,10 +1,10 @@
 # -*- encoding: utf-8 -*-
 #
 #
-# Copyright (C) 2006-2011 Jörg Lehmann <joergl@users.sourceforge.net>
-# Copyright (C) 2007-2011 André Wobst <wobsta@users.sourceforge.net>
+# Copyright (C) 2006-2011 Jörg Lehmann <joerg@pyx-project.org>
+# Copyright (C) 2007-2011 André Wobst <wobsta@pyx-project.org>
 #
-# This file is part of PyX (http://pyx.sourceforge.net/).
+# This file is part of PyX (https://pyx-project.org/).
 #
 # PyX is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -1419,7 +1419,7 @@ class AFMfile(metric.metric):
             flags += 1<<6
         file.write("/Flags %d\n" % flags)
         if self.italicangles[0] is not None:
-            file.write("/ItalicAngles %d\n" % self.italicangles[0])
+            file.write("/ItalicAngle %d\n" % self.italicangles[0])
         if self.ascender is not None:
             ascent = self.ascender
         elif self.fontbbox is not None:
